@@ -42,8 +42,8 @@ CLI_CONFIG = {
         "options": ["-T"],
         "subcommands": ["state"],
     },
-    "cache_dir": {},
-    "root_dir": {},
+    "cache_dir": {"subcommands": ["state"]},
+    "root_dir": {"subcommands": ["state"]},
     "render": {
         "subcommands": ["state"],
     },
@@ -68,7 +68,7 @@ CLI_CONFIG = {
     "acct_file": {
         "source": "acct",
         "os": "ACCT_FILE",
-        "subcommands": ["state", "exec"],
+        "subcommands": ["state", "exec", "describe"],
     },
     "acct_key": {
         "source": "acct",
