@@ -1,7 +1,9 @@
 __func_alias__ = {"ctx_": "ctx"}
+__contracts__ = ["returns", "soft_fail"]
 
 
 def __init__(hub):
+    hub.exec.test.ITEMS = {}
     hub.exec.test.ACCT = ["test"]
 
 
