@@ -1,20 +1,23 @@
 """
 This plugin is used to resolve transparent requisites adn apply them to
 the lowstate
+
+.. code-block:: python
+
+    TREQ = {
+        "func_D": {
+            "require": [
+                "foo.bar.baz.func_A",
+                "test.func_B",
+            ],
+            "soft_require": [
+                "cheese.func_C",
+            ],
+        }
+    }
 """
 import pop.loader
 
-# TREQ = {func_D requires func_a, B, C}
-# TREQ = {'func_D':
-#            'require': [
-#              'foo.bar.baz.func_A',
-#              'test.func_B',
-#              ],
-#            'soft_require': [
-#                'cheese.func_C',
-#                ],
-#            }
-
 
 def gather(hub, subs, low):
     """
@@ -43,32 +46,24 @@ def gather(hub, subs, low):
 
 def apply(hub, subs, low):
     """
-    Look up the transparetn requisites as defined in state modules and apply
+    Look up the transparent requisites as defined in state modules and apply
     them to the respective low chunks
     """
     treq = hub.idem.ccomps.treq.gather(subs, low)
-    refs = {}
-    for ind, chunk in enumerate(low):
-        path = f'{chunk["state"]}.{chunk["fun"]}'
-        if path not in refs:
-            refs[path] = []
-        # I am using a list to maintain requisite ordering. if a set is used
-        # The we will have no deterministic ordering, which would be BAD!!!
-        if ind not in refs[path]:
-            refs[path].append(ind)
     for chunk in low:
         if not chunk["state"] in treq:
             continue
         if not chunk["fun"] in treq[chunk["state"]]:
             continue
         rule = treq[chunk["state"]][chunk["fun"]]
-        for req, r_refs in rule.items():
-            for ref in r_refs:
-                if ref not in refs:
-                    continue
-                for rind in refs[path]:
-                    req_chunk = low[rind]
-                    if req not in chunk:
-                        chunk[req] = []
-                    chunk[req].append({req_chunk["state"]: req_chunk["__id__"]})
+        for rule_name, rule_refs in rule.items():
+            for ref in rule_refs:
+                for req_chunk in low:
+                    req_path = f'{req_chunk["state"]}.{req_chunk["fun"]}'
+                    if req_path == ref:
+                        if rule_name not in chunk:
+                            chunk[rule_name] = []
+                        chunk[rule_name].append(
+                            {req_chunk["state"]: req_chunk["__id__"]}
+                        )
     return low
