@@ -79,7 +79,7 @@ async def cli_apply(hub):
         elif hub.SUBPARSER == "describe":
             retcode = await hub.idem.init.cli_desc()
         else:
-            print(hub.config.args.parser.help())
+            print(hub.args.parser.help())
             retcode = 2
     finally:
         if hub.acct.UNLOCKED:
