@@ -83,6 +83,14 @@ def get_func(hub, name, chunk, fun=None):
     if fun is None:
         fun = chunk["fun"]
     s_ref = chunk["state"]
+
+    # Check if an auto_state exists for this ref
+    try:
+        if "auto_state" in hub.exec[s_ref].__contracts__:
+            chunk["exec_mod_ref"] = s_ref
+            return hub.states.auto_state[fun]
+    except AttributeError or TypeError:
+        ...
     for sub in hub.idem.RUNS[name]["subs"]:
         test = f"{sub}.{s_ref}.{fun}"
         try:
