@@ -20,7 +20,7 @@ async def start(hub, name):
         if seq == old_seq:
             unmet_reqs = {chunk["tag"]: chunk["unmet"] for chunk in seq.values()}
             raise Exception(f"No sequence changed for '{name}': {unmet_reqs}")
-        await getattr(hub, ref)(name, ctx, seq, low, hub.idem.RUNS[name]["running"])
+        await hub[ref](name, ctx, seq, low, hub.idem.RUNS[name]["running"])
         await hub.idem.resolve.render(name)
         await hub.idem.state.compile(name)
         low = hub.idem.RUNS[name].get("low")
