@@ -32,6 +32,8 @@ def display(hub, data):
             tcolor = fg(11)
         elif result is False:
             tcolor = fg(9)
+        else:
+            tcolor = fg(0)
 
         strs.append(f"{tcolor}--------{endc}")
         strs.append(f"{tcolor}      ID: {id_}{endc}")
